@@ -1,20 +1,11 @@
 extern crate rex_tui;
 use rex_tui::db::*;
 use rex_tui::utility::get_all_tx_methods;
-use rusqlite::Connection;
 use std::fs;
 
-fn create_test_db(file_name: &str) -> Connection {
-    if let Ok(metadata) = fs::metadata(file_name) {
-        if metadata.is_file() {
-            fs::remove_file(file_name).expect("Failed to delete existing file");
-        }
-    }
+mod common;
 
-    let mut conn = Connection::open(file_name).unwrap();
-    create_db(&["test1".to_string(), "test 2".to_string()], &mut conn).unwrap();
-    conn
-}
+use crate::common::create_test_db;
 
 #[test]
 fn check_getting_tx_methods_1() {
@@ -25,7 +16,10 @@ fn check_getting_tx_methods_1() {
 
     fs::remove_file(file_name).unwrap();
 
-    assert_eq!(data, vec!["test1".to_string(), "test 2".to_string()]);
+    assert_eq!(
+        data,
+        vec!["Super Special Bank".to_string(), "Cash Cow".to_string()]
+    );
 }
 
 #[test]
@@ -47,8 +41,8 @@ fn check_getting_tx_methods_2() {
     assert_eq!(
         data,
         vec![
-            "test1".to_string(),
-            "test 2".to_string(),
+            "Super Special Bank".to_string(),
+            "Cash Cow".to_string(),
             "new method 1".to_string(),
             "testing methods".to_string()
         ]
